netapp_ontap.models.chassis_node API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.chassis_node`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ChassisNodeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ChassisNode object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the chassis_node.

  `name GET POST PATCH`

    The name field of the chassis_node.

    Example: node1

  `position GET POST PATCH`

    The Position of the Node in the Chassis

    Valid choices:

    - top
    - bottom
    - left
    - right
    - unknown
  `uuid GET POST PATCH`

    The uuid field of the chassis_node.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412